pub fn decode_frame_payload(
cx: &mut Cx,
codec: &Symbol,
payload: &[u8],
read_policy: ReadPolicy,
limits: DecodeLimits,
) -> Result<Expr>Expand description
Decodes a frame payload back into an expression using codec.
The read_policy and limits bound how the payload bytes are parsed.