pub fn eval_reply_from_frame(
cx: &mut Cx,
frame: &ServerFrame,
) -> Result<EvalReply>Expand description
Decodes a response ServerFrame back into an EvalReply.
Returns an error when the frame is not a response frame.
pub fn eval_reply_from_frame(
cx: &mut Cx,
frame: &ServerFrame,
) -> Result<EvalReply>Decodes a response ServerFrame back into an EvalReply.
Returns an error when the frame is not a response frame.