register_wasm_region

Function register_wasm_region 

pub fn register_wasm_region(region: &str, wasm_bytes: &[u8]) -> Result<()>
Registers a wasm guest module under region using the default runtime.

Instantiates wasm_bytes with a wasmi runtime at default frame limits and stores it in the process-wide region registry.