pub struct BodyLimits {
pub max_request_bytes: usize,
pub max_chunk_bytes: usize,
}Expand description
Fixed memory and wire bounds for one raw request.
Fields
max_request_bytes: usizeMaximum bytes accepted for the complete request body.
max_chunk_bytes: usizeMaximum bytes admitted in one read or write chunk.