pub struct FabricEvalSite { /* private fields */ }Expand description
An eval site that delegates requests to a distributed EvalFabric.
Implementations
Sourceimpl FabricEvalSite
impl FabricEvalSite
Sourcepub fn new(
kind: &'static str,
address: ServerAddress,
codecs: Vec<Symbol>,
fabric: Arc<dyn EvalFabric>,
) -> Self
pub fn new( kind: &'static str, address: ServerAddress, codecs: Vec<Symbol>, fabric: Arc<dyn EvalFabric>, ) -> Self
Creates a fabric site labeled kind, answering at address over
codecs, backed by fabric.