pub struct LocalEvalSite { /* private fields */ }Expand description
An eval site that evaluates requests directly in the local runtime.
Implementations
Sourceimpl LocalEvalSite
impl LocalEvalSite
Sourcepub fn new(address: ServerAddress, codecs: Vec<Symbol>) -> Self
pub fn new(address: ServerAddress, codecs: Vec<Symbol>) -> Self
Creates a local site answering at address over codecs.