pub struct RequestScope { /* private fields */ }Expand description
Cancellation and deadline owned by exactly one handler invocation.
Implementations
Sourceimpl RequestScope
impl RequestScope
Sourcepub fn child(parent: &Cancellation, deadline: Duration) -> Self
pub fn child(parent: &Cancellation, deadline: Duration) -> Self
Creates an independent request scope beneath the caller/server lifetime.
Sourcepub fn cancellation(&self) -> &Cancellation
pub fn cancellation(&self) -> &Cancellation
Returns the request cancellation observer.
Sourcepub fn cancel_timeout(&self)
pub fn cancel_timeout(&self)
Records that the injected platform clock reached the request deadline.
Sourcepub fn cancel_peer_drop(&self)
pub fn cancel_peer_drop(&self)
Records EOF or another peer-side disconnect observed by the connection adapter.