ResolvedAddress

Struct ResolvedAddress 

pub struct ResolvedAddress {
    pub site: Arc<dyn EvalSite>,
    pub selected_codec: Symbol,
    pub supported_codecs: Vec<Symbol>,
}
Outcome of resolving a ServerAddress to a concrete eval site and codec set.

Fields

site: Arc<dyn EvalSite>

Eval site that handles frames for the resolved address.

selected_codec: Symbol

Codec selected for the connection.

supported_codecs: Vec<Symbol>

Codecs the resolved site supports.