RawConnection

Trait RawConnection 

pub trait RawConnection {
    // Required method
    fn parts(
        &mut self,
    ) -> (&RequestHead, &mut dyn BodyReader, &mut dyn ResponseWriter);
}
Raw connection after the shared accept loop and HTTP parser have produced a request head.

Required Methods

fn parts( &mut self, ) -> (&RequestHead, &mut dyn BodyReader, &mut dyn ResponseWriter)

Borrows the parsed head and independent streaming halves together.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors