pub struct CookbookWebState { /* private fields */ }Expand description
Cookbook state exposed by the WebUI route and JSON API.
Implementations
Sourceimpl CookbookWebState
impl CookbookWebState
Sourcepub fn seeded() -> Result<Self>
pub fn seeded() -> Result<Self>
Build a WebUI state from the crate-shipped seeded recipe books.
Sourcepub fn from_store(store: RecipeStore) -> Self
pub fn from_store(store: RecipeStore) -> Self
Build a WebUI state from an existing recipe store.
Sourcepub fn store(&self) -> &RecipeStore
pub fn store(&self) -> &RecipeStore
Access the backing cookbook store.
Sourcepub fn handle_request(
&self,
method: &str,
target: &str,
cx: Option<&mut Cx>,
) -> CookbookWebResponse
pub fn handle_request( &self, method: &str, target: &str, cx: Option<&mut Cx>, ) -> CookbookWebResponse
Route one cookbook WebUI request.
target is an HTTP request target such as /api/cookbook?q=x. The run
endpoint requires a runtime context because it executes the same
sim-lib-cookbook recipe runner used by the runtime ops and CLI.