pub struct LoopEvalSite { /* private fields */ }Expand description
An eval site that repeatedly runs its pipeline steps – up to
max_iterations times – until the until predicate fires on a reply.
Implementations
Sourceimpl LoopEvalSite
impl LoopEvalSite
Sourcepub fn new(
address: ServerAddress,
codecs: Vec<Symbol>,
steps: Vec<Connection>,
max_iterations: usize,
until: Value,
) -> Self
pub fn new( address: ServerAddress, codecs: Vec<Symbol>, steps: Vec<Connection>, max_iterations: usize, until: Value, ) -> Self
Creates a loop site answering at address over codecs, running steps
at most max_iterations times or until until fires.