pub struct RawHttpServer<H> { /* private fields */ }Expand description
Policy-bearing dispatcher used by the existing HTTP accept/parser loop.
Implementations
Sourceimpl<H: RawHandler> RawHttpServer<H>
impl<H: RawHandler> RawHttpServer<H>
Sourcepub fn new(
handler: H,
limits: BodyLimits,
trailers: TrailersPolicy,
request_deadline: Duration,
) -> Result<Self>
pub fn new( handler: H, limits: BodyLimits, trailers: TrailersPolicy, request_deadline: Duration, ) -> Result<Self>
Creates a raw dispatcher. It deliberately does not create a listener or runtime.
Sourcepub fn serve(
&self,
connection: &mut dyn RawConnection,
caller: &Cancellation,
) -> Result<()>
pub fn serve( &self, connection: &mut dyn RawConnection, caller: &Cancellation, ) -> Result<()>
Dispatches one already parsed connection through a fresh request scope.